;; Generated package description from js2-mode.el
(define-package "js2-mode" "20141115" "Improved JavaScript editing mode" '((emacs "24.1")) :url "https://github.com/mooz/js2-mode/" :keywords '("languages" "javascript"))
